from setuptools import setup

setup(name='Jiyatesting',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['Jiyatesting'],
      author = "Jiya",
      zip_safe = False)
